OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "Ezin izan da %s betirako ezabatu",
    "Couldn't restore %s" : "Ezin izan da %s berreskuratu",
    "Deleted files" : "Ezabatutako fitxategiak",
    "Restore" : "Berrezarri",
    "Delete" : "Ezabatu",
    "Delete permanently" : "Ezabatu betirako",
    "Error" : "Errorea",
    "restored" : "Berrezarrita",
    "No deleted files" : "Ez dago ezabatutako fitxategirik",
    "You will be able to recover deleted files from here" : "Hemendik ezabatutako fitxategiak berreskuratu ahal izango duzu",
    "No entries found in this folder" : "Ez da sarrerarik aurkitu karpeta honetan",
    "Select all" : "Hautatu dena",
    "Name" : "Izena",
    "Deleted" : "Ezabatuta",
    "This operation is forbidden" : "Eragiketa hau debekatuta dago",
    "This directory is unavailable, please check the logs or contact the administrator" : "Direktoria ez dago eskuragarri; mesedez, log-ak begiratu edo harremanetan jarri administratzailearekin"
},
"nplurals=2; plural=(n != 1);");
